@@ -161,14 +161,14 @@ cutLexis <- function(data,
              "),\n --- but it has length ", length(cut),".")
       }
 
-    timescale <- Epi:::check.time.scale(data, timescale)
+    timescale <- check.time.scale(data, timescale)
     if (length(timescale) > 1) {
         stop("Multiple time scales")
     }
 
     ## If we want to add a new timescale, construct the name
     if( is.logical(new.scale) ) {
-      if( new.scale ) scale.name <- paste( new.state[1], "dur", sep="." )
+      if( new.scale ) scale.name <- paste( "tf", new.state[1], sep="" )
       }
     else {
       scale.name <- new.scale
@@ -247,6 +247,7 @@ cutLexis <- function(data,
       new.br <- c( attr( data, "breaks" ), list(NULL) )
       names( new.br )[length(new.br)] <- scale.name
       attr( lx, "time.scales" ) <- c( attr( data, "time.scales" ), scale.name )
+      attr( lx, "time.since" )  <- c( attr( data, "time.since" ), names(table(new.state)) )
       attr( lx, "breaks" )      <- new.br
       attr( lx, "class" )       <- attr( data, "class" )
       }
@@ -256,6 +257,7 @@ cutLexis <- function(data,
       lx <- lx[order(lx$lex.id,lx[,timescale]),-match("lex.new.scale",names(lx))]
       # and transfer all the other attributes
       attr( lx, "time.scales" ) <- attr( data, "time.scales" )
+      attr( lx, "time.since" )  <- attr( data, "time.since" )
       attr( lx, "breaks" )      <- attr( data, "breaks" )
       attr( lx, "class" )       <- attr( data, "class" )
       }
@@ -280,7 +282,7 @@ countLexis <- function(data, cut, timescale = 1)
              "),\n --- but it has length ", length(cut),".")
       }
 
-    timescale <- Epi:::check.time.scale(data, timescale)
+    timescale <- check.time.scale(data, timescale)
     if (length(timescale) > 1) {
         stop("Multiple time scales not meaningful")
     }
