@@ -1,8 +1,16 @@
-### R code from vignette source 'simLexis.rnw'
+### R code from vignette source 'simLexis'
 ### Encoding: UTF-8
 
 ###################################################
-### code chunk number 1: start
+### code chunk number 1: simLexis.rnw:24-27
+###################################################
+options( width=90,
+         SweaveHooks=list( fig=function()
+         par(mar=c(3,3,1,1),mgp=c(3,1,0)/1.6,las=1,bty="n") ) )
+
+
+###################################################
+### code chunk number 2: start
 ###################################################
 options( width=90 )
 library( Epi )
@@ -10,7 +18,7 @@ print( sessionInfo(), l=F )
 
 
 ###################################################
-### code chunk number 2: Lexis
+### code chunk number 3: Lexis
 ###################################################
 data(DMlate)
 dml <- Lexis( entry = list(Per=dodm, Age=dodm-dobth, DMdur=0 ),
@@ -20,7 +28,7 @@ dml <- Lexis( entry = list(Per=dodm, Age=dodm-dobth, DMdur=0 ),
 
 
 ###################################################
-### code chunk number 3: cut
+### code chunk number 4: cut
 ###################################################
 dmi <- cutLexis( dml, cut = dml$doins,
                       pre = "DM",
@@ -32,16 +40,15 @@ str(dmi)
 
 
 ###################################################
-### code chunk number 4: boxes
+### code chunk number 5: boxes
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 boxes( dmi, boxpos = list(x=c(20,20,80,80),
                         y=c(80,20,80,20)),
             scale.R = 1000, show.BE = TRUE )
 
 
 ###################################################
-### code chunk number 5: split
+### code chunk number 6: split
 ###################################################
 Si <- splitLexis( dmi, 0:30/2, "DMdur" )
 dim( Si )
@@ -49,7 +56,7 @@ print( subset( Si, lex.id==97 )[,1:10], digits=6 )
 
 
 ###################################################
-### code chunk number 6: knots
+### code chunk number 7: knots
 ###################################################
 nk <- 5
 ( ai.kn <- with( subset(Si,lex.Xst=="Ins" & lex.Cst!=lex.Xst ),
@@ -65,7 +72,7 @@ nk <- 5
 
 
 ###################################################
-### code chunk number 7: Poisson
+### code chunk number 8: Poisson
 ###################################################
 library( splines )
 DM.Ins <- glm( (lex.Xst=="Ins") ~ Ns( Age  , knots=ai.kn ) +
@@ -87,7 +94,7 @@ Ins.Dead <- glm( (lex.Xst=="Dead(Ins)") ~ Ns( Age  , knots=ad.kn ) +
 
 
 ###################################################
-### code chunk number 8: prop-haz
+### code chunk number 9: prop-haz
 ###################################################
 with( Si, table(lex.Cst) )
 All.Dead <- glm( (lex.Xst %in% c("Dead(Ins)","Dead")) ~
@@ -101,7 +108,7 @@ round( ci.exp( All.Dead ), 3 )
 
 
 ###################################################
-### code chunk number 9: get-dev
+### code chunk number 10: get-dev
 ###################################################
 what <- c("null.deviance","df.null","deviance","df.residual")
 ( rD <- unlist(  DM.Dead[what] ) )
@@ -111,7 +118,7 @@ round( c( dd <- rA-(rI+rD), "pVal"=1-pchisq(dd[3],dd[4]+1) ), 3 )
 
 
 ###################################################
-### code chunk number 10: pr-array
+### code chunk number 11: pr-array
 ###################################################
 pr.rates <- NArray( list( DMdur = seq(0,12,0.1),
                           DMage = 4:7*10,
@@ -122,13 +129,13 @@ str( pr.rates )
 
 
 ###################################################
-### code chunk number 11: simLexis.rnw:515-516
+### code chunk number 12: simLexis.rnw:382-383
 ###################################################
 ci.pred
 
 
 ###################################################
-### code chunk number 12: make-pred
+### code chunk number 13: make-pred
 ###################################################
 nd <- data.frame( DMdur = as.numeric( dimnames(pr.rates)[[1]] ),
                 lex.Cst = factor( 1, levels=1:4,
@@ -154,9 +161,8 @@ pr.rates[,ia, ii ,"All"   ,] <- ci.pred( All.Dead, newdata = dnew )
 
 
 ###################################################
-### code chunk number 13: mort-int
+### code chunk number 14: mort-int
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 par( mar=c(3,3,1,1), mgp=c(3,1,0)/1.6, las=1 )
 plot( NA, xlim=c(40,82), ylim=c(5,300), bty="n",
       log="y", xlab="Age", ylab="Mortality rate per 1000 PY" )
@@ -170,7 +176,7 @@ for( aa in 4:7*10 ) for( ii in 1:4 )
 
 
 ###################################################
-### code chunk number 14: Tr
+### code chunk number 15: Tr
 ###################################################
 Tr <- list( "DM" = list( "Ins"       = DM.Ins,
                          "Dead"      = DM.Dead  ),
@@ -178,7 +184,7 @@ Tr <- list( "DM" = list( "Ins"       = DM.Ins,
 
 
 ###################################################
-### code chunk number 15: make-ini
+### code chunk number 16: make-ini
 ###################################################
 str( Si[NULL,1:9] )
 ini <- subset(Si,FALSE,select=1:9)
@@ -188,7 +194,7 @@ str( ini )
 
 
 ###################################################
-### code chunk number 16: ini-fill
+### code chunk number 17: ini-fill
 ###################################################
 ini[1:2,"lex.id"] <- 1:2
 ini[1:2,"lex.Cst"] <- "DM"
@@ -200,10 +206,10 @@ ini
 
 
 ###################################################
-### code chunk number 17: simL
+### code chunk number 18: simL
 ###################################################
 set.seed( 52381764 )
-Nsim <- 1000
+Nsim <- 5000
 system.time( simL <- simLexis( Tr,
                               ini,
                           t.range = 12,
@@ -211,13 +217,13 @@ system.time( simL <- simLexis( Tr,
 
 
 ###################################################
-### code chunk number 18: sum-simL
+### code chunk number 19: sum-simL
 ###################################################
 summary( simL, by="sex" )
 
 
 ###################################################
-### code chunk number 19: Tr.p-simP
+### code chunk number 20: Tr.p-simP
 ###################################################
 Tr.p <- list( "DM" = list( "Ins"       = DM.Ins,
                            "Dead"      = All.Dead  ),
@@ -230,7 +236,7 @@ summary( simP, by="sex" )
 
 
 ###################################################
-### code chunk number 20: Cox-dur
+### code chunk number 21: Cox-dur
 ###################################################
 library( survival )
 Cox.Dead <- coxph( Surv( DMdur, DMdur+lex.dur,
@@ -244,7 +250,7 @@ round( ci.exp( All.Dead ), 3 )
 
 
 ###################################################
-### code chunk number 21: TR.c
+### code chunk number 22: TR.c
 ###################################################
 Tr.c <- list( "DM" = list( "Ins"       = Tr$DM$Ins,
                            "Dead"      = Cox.Dead  ),
@@ -257,7 +263,7 @@ summary( simC, by="sex" )
 
 
 ###################################################
-### code chunk number 22: nState
+### code chunk number 23: nState
 ###################################################
 system.time(
 nSt <- nState( subset(simL,sex=="M"),
@@ -266,9 +272,8 @@ nSt[1:10,]
 
 
 ###################################################
-### code chunk number 23: pstate0
+### code chunk number 24: pstate0
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 pM <- pState( nSt, perm=c(1,2,4,3) )
 head( pM )
 par( mfrow=c(1,2), mar=c(3,3,1,1), mgp=c(3,1,0)/1.6 )
@@ -282,9 +287,8 @@ box()
 
 
 ###################################################
-### code chunk number 24: pstatex
+### code chunk number 25: pstatex
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 clr <- c("limegreen","orange")
 # expand with a lighter version of the two chosen colors
 clx <- c( clr, rgb( t( col2rgb( clr[2:1] )*2 + rep(255,3) ) / 3, max=255 ) )
@@ -294,8 +298,8 @@ plot( pM, col=clx )
 lines( as.numeric(rownames(pM)), pM[,2], lwd=3 )
 mtext( "60 year old male, diagnosed 1990, aged 55", side=3, line=2.5, adj=0, col=gray(0.6) )
 mtext( "Survival curve", side=3, line=1.5, adj=0 )
-mtext( "DM, no insulin   DM, Insulin", side=3, line=0.5, adj=0, col=clr[1] )
-mtext( "DM, no insulin", side=3, line=0.5, adj=0, col=clr[2] )
+mtext( "DM, no insulin   DM, Insulin", side=3, line=0.5, adj=0, col=clr[2] )
+mtext( "DM, no insulin", side=3, line=0.5, adj=0, col=clr[1] )
 axis( side=4 )
 axis( side=4, at=1:19/20, labels=FALSE )
 axis( side=4, at=1:99/100, labels=FALSE, tcl=-0.3 )
@@ -317,9 +321,8 @@ axis( side=4, at=1:99/100, labels=FALSE, tcl=-0.3 )
 
 
 ###################################################
-### code chunk number 25: pstatey
+### code chunk number 26: pstatey
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 par( mfrow=c(1,2), las=1, mar=c(3,3,4,2), mgp=c(3,1,0)/1.6 )
 # Men
 pM <- pState( nState( subset(simL,sex=="M"),
@@ -331,8 +334,8 @@ plot( pM, col=clx, xlab="Age" )
 lines( as.numeric(rownames(pM)), pM[,2], lwd=3 )
 mtext( "60 year old male, diagnosed 1990, aged 55", side=3, line=2.5, adj=0, col=gray(0.6) )
 mtext( "Survival curve", side=3, line=1.5, adj=0 )
-mtext( "DM, no insulin   DM, Insulin", side=3, line=0.5, adj=0, col=clr[1] )
-mtext( "DM, no insulin", side=3, line=0.5, adj=0, col=clr[2] )
+mtext( "DM, no insulin   DM, Insulin", side=3, line=0.5, adj=0, col=clr[2] )
+mtext( "DM, no insulin", side=3, line=0.5, adj=0, col=clr[1] )
 axis( side=4 )
 axis( side=4, at=1:19/20, labels=FALSE )
 axis( side=4, at=1:19/20, labels=FALSE, tcl=-0.4 )
@@ -356,9 +359,8 @@ axis( side=4, at=1:99/100, labels=FALSE, tcl=-0.3 )
 
 
 ###################################################
-### code chunk number 26: comp-0
+### code chunk number 27: comp-0
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 PrM  <- pState( nState( subset(simP,sex=="M"),
                         at=seq(0,11,0.2),
                         from=60,
@@ -395,13 +397,13 @@ box( lwd=3 )
 
 
 ###################################################
-### code chunk number 27: CHANGE1 (eval = FALSE)
+### code chunk number 28: CHANGE1 (eval = FALSE)
 ###################################################
 ## source( "../R/simLexis.R", keep.source=TRUE )
 
 
 ###################################################
-### code chunk number 28: CHANGE2
+### code chunk number 29: CHANGE2
 ###################################################
 simX <- Epi:::simX
 sim1 <- Epi:::sim1
@@ -411,7 +413,7 @@ chop.lex <- Epi:::chop.lex
 
 
 ###################################################
-### code chunk number 29: simLexis.rnw:1065-1068
+### code chunk number 30: simLexis.rnw:934-937
 ###################################################
 cbind(
 attr( ini, "time.scale" ),
@@ -419,55 +421,55 @@ attr( ini, "time.since" ) )
 
 
 ###################################################
-### code chunk number 30: simLexis.rnw:1093-1094
+### code chunk number 31: simLexis.rnw:962-963
 ###################################################
 simLexis
 
 
 ###################################################
-### code chunk number 31: simLexis.rnw:1111-1112
+### code chunk number 32: simLexis.rnw:980-981
 ###################################################
 simX
 
 
 ###################################################
-### code chunk number 32: simLexis.rnw:1124-1125
+### code chunk number 33: simLexis.rnw:993-994
 ###################################################
 sim1
 
 
 ###################################################
-### code chunk number 33: simLexis.rnw:1137-1138
+### code chunk number 34: simLexis.rnw:1006-1007
 ###################################################
 lint
 
 
 ###################################################
-### code chunk number 34: simLexis.rnw:1148-1149
+### code chunk number 35: simLexis.rnw:1017-1018
 ###################################################
 get.next
 
 
 ###################################################
-### code chunk number 35: simLexis.rnw:1158-1159
+### code chunk number 36: simLexis.rnw:1027-1028
 ###################################################
 chop.lex
 
 
 ###################################################
-### code chunk number 36: simLexis.rnw:1176-1177
+### code chunk number 37: simLexis.rnw:1045-1046
 ###################################################
 nState
 
 
 ###################################################
-### code chunk number 37: simLexis.rnw:1186-1187
+### code chunk number 38: simLexis.rnw:1055-1056
 ###################################################
 pState
 
 
 ###################################################
-### code chunk number 38: simLexis.rnw:1191-1193
+### code chunk number 39: simLexis.rnw:1060-1062
 ###################################################
 plot.pState
 lines.pState
